summaryrefslogtreecommitdiff
path: root/arch/s390/boot
diff options
context:
space:
mode:
authorAlexander Egorenkov <egorenar@linux.ibm.com>2021-06-15 16:59:32 +0300
committerHeiko Carstens <hca@linux.ibm.com>2021-07-27 10:39:15 +0300
commit8b6bd6f295b7ff5e3205ef135de8ad3b2034ed73 (patch)
tree923194a6c8d8b3051ea0c1618b19131c4e9f7cba /arch/s390/boot
parent36af1c5c1598453b29cf3529dd57e58db3e11d19 (diff)
downloadlinux-8b6bd6f295b7ff5e3205ef135de8ad3b2034ed73.tar.xz
s390/boot: get rid of magic numbers for startup offsets
Use STARTUP_NORMAL_OFFSET and STARTUP_KDUMP_OFFSET instead of magic numbers. Signed-off-by: Alexander Egorenkov <egorenar@linux.ibm.com> Acked-by: Heiko Carstens <hca@linux.ibm.com> Signed-off-by: Heiko Carstens <hca@linux.ibm.com>
Diffstat (limited to 'arch/s390/boot')
-rw-r--r--arch/s390/boot/head.S8
1 files changed, 4 insertions, 4 deletions
diff --git a/arch/s390/boot/head.S b/arch/s390/boot/head.S
index 0cfa76fe6dfd..4ac3958b3032 100644
--- a/arch/s390/boot/head.S
+++ b/arch/s390/boot/head.S
@@ -274,11 +274,11 @@ iplstart:
.Lcpuid:.fill 8,1,0
#
# startup-code at 0x10000, running in absolute addressing mode
# this is called either by the ipl loader or directly by PSW restart
# or linload or SALIPL
#
- .org 0x10000
+ .org STARTUP_NORMAL_OFFSET
SYM_CODE_START(startup)
j startup_normal
.org EP_OFFSET
@@ -291,9 +291,9 @@ SYM_CODE_START(startup)
.ascii EP_STRING
.byte 0x00,0x01
#
-# kdump startup-code at 0x10010, running in 64 bit absolute addressing mode
+# kdump startup-code, running in 64 bit absolute addressing mode
#
- .org 0x10010
+ .org STARTUP_KDUMP_OFFSET
j startup_kdump
SYM_CODE_END(startup)
SYM_CODE_START_LOCAL(startup_normal)
@@ -274,11 +274,11 @@ iplstart:
.Lcpuid:.fill 8,1,0
#
-# startup-code at 0x10000, running in absolute addressing mode
+# normal startup-code, running in absolute addressing mode
# this is called either by the ipl loader or directly by PSW restart
# or linload or SALIPL